==> haskell-json-ast-0.3.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-json-ast.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json-ast
version: 0.3.1
id: json-ast-0.3.1-7KCJpduAvGc2A0fUtVNGHZ
key: json-ast-0.3.1-7KCJpduAvGc2A0fUtVNGHZ
license: MIT
copyright: (c) 2016, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/json-ast
synopsis: Universal JSON AST datastructure
abi: 223735a57d1743f66bb42168322298cb
exposed: True
exposed-modules:
    JSONAST
import-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/json-ast-0.3.1
hs-libraries: HSjson-ast-0.3.1-7KCJpduAvGc2A0fUtVNGHZ
depends:
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq text-1.2.3.0
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu base-4.11.1.0
abi-depends: vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-json-ast/html/json-ast.haddock
haddock-html: /usr/share/doc/haskell-json-ast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-json-ast-0.3.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-json-ast.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: json-ast
version: 0.3.1
id: json-ast-0.3.1-IkDfEh9okQCBQd7g7yqROt
key: json-ast-0.3.1-IkDfEh9okQCBQd7g7yqROt
license: MIT
copyright: (c) 2016, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/json-ast
synopsis: Universal JSON AST datastructure
abi: 12b54cf9593409fb898594fe9005300c
exposed: True
exposed-modules:
    JSONAST
import-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/json-ast-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/json-ast-0.3.1
hs-libraries: HSjson-ast-0.3.1-IkDfEh9okQCBQd7g7yqROt
depends:
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq text-1.2.3.0
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd base-4.11.1.0
abi-depends: vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-json-ast/html/json-ast.haddock
haddock-html: /usr/share/doc/haskell-json-ast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
